==> wormux_0.7.9.orig.tar.gz: wormux-0.7.9/src/weapon/skip_turn.h <==
/******************************************************************************
 *  Wormux is a convivial mass murder game.
 *  Copyright (C) 2001-2004 Lawrence Azzoug.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 ******************************************************************************
 * Skip turn.
 *****************************************************************************/

#ifndef SKIP_TURN_H
#define SKIP_TURN_H
//-----------------------------------------------------------------------------
#include "weapon.h"
//-----------------------------------------------------------------------------

class SkipTurn : public Weapon
{
  public:
    SkipTurn();
  protected:
    bool p_Shoot();
    void Refresh();
};

//-----------------------------------------------------------------------------
#endif /* SKIP_TURN_H */

==> wormux_0.8.5.orig.tar.gz: wormux-0.8.5/src/weapon/skip_turn.h <==
/******************************************************************************
 *  Wormux is a convivial mass murder game.
 *  Copyright (C) 2001-2009 Wormux Team.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 ******************************************************************************
 * Skip turn.
 *****************************************************************************/

#ifndef SKIP_TURN_H
#define SKIP_TURN_H
//-----------------------------------------------------------------------------
#include "weapon.h"
//-----------------------------------------------------------------------------

class SkipTurn : public Weapon
{
  public:
    SkipTurn();

    void UpdateTranslationStrings();
    std::string GetWeaponWinString(const char *TeamName, uint items_count ) const;
    bool IsInUse() const;
  protected:
    bool p_Shoot();
    void Refresh() { };
};

//-----------------------------------------------------------------------------
#endif /* SKIP_TURN_H */
